from __future__ import unicode_literals

from .base import OmniSDKTestCase

# TODO add tests
class ApiEndpointTestCase(OmniSDKTestCase):
    def test_endpoint_url_is_correct(self):
        pass

    def test_create(self):
        pass

    def test_retrieve(self):
        pass

    def test_update(self):
        pass

    def test_delete(self):
        pass

    def test_list(self):
        pass
